Coverage for src\derivepassphrase\_internals\__init__.py: 100.000%

1# SPDX-FileCopyrightText: 2025 Marco Ricci <software@the13thletter.info>

2#

3# SPDX-License-Identifier: Zlib

4

5"""derivepassphrase internals.

6

7 Warning:

8 Non-public package (implementation detail), provided for didactical

9 and educational purposes only. Subject to change without notice,

10 including removal.

11

12"""

13

14 import derivepassphrase (empty)

15

16 __all__ = () (empty)

17

18 PROG_NAME = derivepassphrase.__distribution_name__ (empty)

19 VERSION = derivepassphrase.__version__ (empty)

20 AUTHOR = derivepassphrase.__author__ (empty)